@@ -10,7 +10,6 @@ OC.L10N.register(
     "Copy link" : "Copiar liga",
     "Download" : "Descargar",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
-    "can edit" : "puede editar",
     "Cancel" : "Cancelar",
     "Add" : "Agregar",
     "First name" : "Nombre",
@@ -91,10 +90,6 @@ OC.L10N.register(
     "Gender" : "Género",
     "Female" : "Femenino",
     "Male" : "Masculino",
-    "Unknown" : "Desconocido",
-    "Loading contacts …" : "Cargando contactos ...",
-    "Loading …" : "Cargando …",
-    "General settings" : "Configuraciones generales",
-    "Search contacts …" : "Buscar contactos ..."
+    "Unknown" : "Desconocido"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
