@@ -287,6 +287,9 @@ OC.L10N.register(
     "You are about to delete {circle}.\nAre you sure?" : "您即將刪除 {circle}。\n你確定嗎？",
     "Please confirm team deletion" : "請確認您要刪除團隊",
     "Unable to delete the team" : "無法刪除這個團隊",
+    "Confirm enabling federation" : "確認啟用聯邦功能",
+    "Enabling this will prevent {circle} from being a member of other teams.\nAre you sure?" : "啟用後，{circle} 將不能加入其他團隊。\n是否確定？",
+    "Enable federation" : "啟用聯邦",
     "Link copied to the clipboard" : "已複製連結至剪貼板",
     "Could not copy link to the clipboard." : "無法複製連結至剪貼板",
     "Not grouped" : "未歸類",
@@ -314,6 +317,8 @@ OC.L10N.register(
     "users" : "用戶",
     "Users" : "用戶",
     "groups" : "群組",
+    "federated users" : "聯盟用戶",
+    "Federated users" : "聯盟用戶",
     "teams" : "團隊",
     "email addresses" : "電郵地址",
     "Email addresses" : "電郵地址",
@@ -384,18 +389,6 @@ OC.L10N.register(
     "Unable to delete team {circleId}" : "無法刪除團隊 {circleId}",
     "Unable to delete contact" : "無法刪除聯絡人",
     "Value copied to the clipboard" : "已複製數值至剪貼板",
-    "Could not copy value to the clipboard." : "無法複製數值至剪貼板",
-    "Loading contacts …" : "正在載入通訊錄 …",
-    "Loading …" : "正在載入 …",
-    "General settings" : "一般設定",
-    "(refreshed once per week)" : "（每週重新整理一次）",
-    "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
-    "can edit" : "允許編輯",
-    "Unique password …" : "獨一無二的密碼 ...",
-    "Search contacts …" : "搜尋聯絡人…",
-    "Invite members to team" : "邀請成員加入團隊",
-    "Loading members list …" : "正在加載成員清單 …",
-    "Add to {circle}" : "添加到 {circle}",
-    "Select chart …" : "選擇圖表 ..."
+    "Could not copy value to the clipboard." : "無法複製數值至剪貼板"
 },
 "nplurals=1; plural=0;");
